@@ -2,12 +2,8 @@ package Data::Record::Serialize::Encode::types_nis;
 
 use Moo::Role;
 
-before BUILD => sub {
-
-    $_[0]->_set__use_integer( 1 );
-
-};
-
+has '+_need_types' => ( is => 'rwp', default => 1 );
+has '+_use_integer' => ( is => 'rwp', default => 1 );
 
 with 'Data::Record::Serialize::Encode::null';
 with 'Data::Record::Serialize::Sink::null';
